@@ -5,7 +5,7 @@ from contextlib import contextmanager
 from enum import Flag, auto
 from pathlib import Path
 
-from pyqtgraph.Qt import QtCore, QtWidgets
+from pyqtgraph.Qt import QtCore, QtWidgets, QtGui
 from pyqtgraph.parametertree import Parameter
 from pyqtgraph.parametertree.parameterTypes import GroupParameter
 
@@ -220,7 +220,7 @@ class ParamEditor(QtWidgets.QDockWidget):
       #   way of waiting the right amount of time
       QtCore.QTimer.singleShot(5, lambda: self.loadParamValues(self.stateName))
 
-  def applyChanges(self, newName: FilePath=None, newState: dict=None, recreate=False):
+  def applyChanges(self, newName: FilePath=None, newState: dict=None):
     """
     Broadcasts that this parameter editor has updated changes
 
@@ -758,6 +758,9 @@ class ParamEditorDockGrouping(QtWidgets.QDockWidget):
 
     self.biggestMinWidth = 0
 
+    self.win = None
+    """Reference to main window if added to one, to resize docks to required width"""
+
   def addEditors(self, editors: t.Sequence[ParamEditor]):
     minWidth = 0
     for editor in editors:
@@ -804,6 +807,12 @@ class ParamEditorDockGrouping(QtWidgets.QDockWidget):
       editor.createMenuOpt(overrideName=nameWithoutBase, parentMenu=parentMenu)
     return parentMenu
 
+  def showEvent(self, ev: QtGui.QShowEvent):
+    super().showEvent(ev)
+    self.raise_()
+    self.activateWindow()
+    if self.width() < self.biggestMinWidth + 100 and self.win:
+      self.win.resizeDocks([self], [self.biggestMinWidth + 100], QtCore.Qt.Horizontal)
 
 class EditorPropsMixin:
   __groupingName__: str = None
