@@ -1,6 +1,7 @@
 from __future__ import annotations
 
 import contextlib
+import typing
 import typing as t
 from textwrap import wrap
 from warnings import warn
@@ -154,17 +155,52 @@ class ScrollableErrorDialog(QtWidgets.QDialog):
     ok.setFocus()
     updateTxt()
 
+class StringListValidator(QtGui.QValidator):
+
+  def __init__(self, parent=None, strList: t.Sequence[str]=None,
+               model: QtCore.QStringListModel=None,
+               validateCase=False) -> None:
+    super().__init__(parent)
+    self.validateCase = validateCase
+    self.strList = strList
+    self.model = model
+
+  def validate(self, input_: str, pos: int):
+    if self.model:
+      self.strList = [self.model.index(ii, 0).data() for ii in range(self.model.rowCount())]
+    strList = cmpStrList = [input_] if self.strList is None else self.strList
+    cmpInput = input_
+    if not self.validateCase:
+      cmpInput = input_.lower()
+      cmpStrList = [s.lower() for s in strList]
+
+    try:
+      matchIdx = cmpStrList.index(cmpInput)
+      input_ = strList[matchIdx]
+      state = self.State.Acceptable
+    except ValueError:
+      if any(cmpInput in str_ for str_ in cmpStrList):
+        state = self.State.Intermediate
+      else:
+        state = self.State.Invalid
+    return state, input_, pos
+
 class PopupLineEditor(QtWidgets.QLineEdit):
   def __init__(self, parent: QtWidgets.QWidget=None, model: QtCore.QAbstractItemModel=None,
                placeholderText='Press Tab or type...', clearOnComplete=True,
-               forceMatch=True):
+               forceMatch=True, validateCase=False):
     super().__init__(parent)
     self.setPlaceholderText(placeholderText)
     self.clearOnComplete = clearOnComplete
     self.forceMatch = forceMatch
+    self.validateCase = validateCase
     self.model: QtCore.QAbstractListModel = QtCore.QStringListModel()
     if model is None:
       model = self.model
+
+    self.vdator = StringListValidator(parent=self, validateCase=validateCase)
+    self.setValidator(self.vdator)
+
     self.setModel(model)
 
   def setModel(self, model: QtCore.QAbstractListModel):
@@ -179,6 +215,8 @@ class PopupLineEditor(QtWidgets.QLineEdit):
 
     self.setCompleter(completer)
     self.model = model
+    if self.forceMatch:
+      self.vdator.model = model
 
   # TODO: Get working with next prev focusing for smoother logic
   # def focusNextPrevChild(self, nextChild: bool):
